@@ -26,6 +26,21 @@ module Debian.Control
     , formatControl
     , formatParagraph
     , formatField
+    -- * Policy classes and functions
+    , P.HasDebianControl(..)
+    , P.ControlFileError(..)
+    , P.parseDebianControlFromFile
+    , P.validateDebianControl
+    , P.unsafeDebianControl
+    , P.debianSourceParagraph
+    , P.debianBinaryParagraphs
+    , P.debianPackageParagraphs
+    , P.debianPackageNames
+    , P.debianSourcePackageName
+    , P.debianBinaryPackageNames
+    , P.debianRelations
+    , P.debianBuildDeps
+    , P.debianBuildDepsIndep
     ) where
 
 --import Control.Monad
@@ -38,6 +53,7 @@ import Data.List
 import Data.Text as T (Text, pack, concat)
 import qualified Debian.Control.Text as T
 import qualified Debian.Control.ByteString as B ()
+import qualified Debian.Control.Policy as P
 import qualified Debian.Control.String as S
 
 packParagraph :: S.Paragraph -> T.Paragraph
