@@ -1,4 +1,4 @@
-{-# LANGUAGE OverloadedStrings, RecordWildCards, ScopedTypeVariables #-}
+{-# LANGUAGE FlexibleContexts, OverloadedStrings, RecordWildCards, ScopedTypeVariables, TemplateHaskell #-}
 -- |Figure out the dependency relation between debianized source
 -- directories.  The code to actually solve these dependency relations
 -- for a particular set of binary packages is in Debian.Repo.Dependency.
@@ -12,6 +12,7 @@ module Debian.GenBuildDeps
     , oldRelaxDeps
     -- * Using dependency info
     , BuildableInfo(..)
+    , ReadyTarget(..)
     , buildable
     , compareSource
     -- * Obsolete?
@@ -21,17 +22,20 @@ module Debian.GenBuildDeps
     , getSourceOrder
     ) where
 
+import           Control.Applicative ((<$>))
+import           Control.Exception (throw)
 import		 Control.Monad (filterM)
-import		 Debian.Control
-import           Data.Either
 import		 Data.Graph (Graph, Edge, buildG, topSort, reachable, transposeG, vertices, edges)
 import		 Data.List
 import qualified Data.Map as Map
 import		 Data.Maybe
 import qualified Data.Set as Set
-import           Data.Text (Text, unpack)
+import		 Debian.Control (parseControlFromFile)
+import		 Debian.Control.Policy (HasDebianControl, ControlFileError(..), validateDebianControl, debianSourcePackageName, debianBinaryPackageNames, debianBuildDeps, debianBuildDepsIndep)
+import           Debian.Loc (__LOC__, mapExn)
 import		 Debian.Relation
 import		 Debian.Relation.Text ()
+import           Language.Haskell.TH (Loc)
 import		 System.Directory (getDirectoryContents, doesFileExist)
 
 -- | This type describes the build dependencies of a source package.
@@ -41,36 +45,15 @@ data DepInfo = DepInfo {
     , binaryNames :: [BinPkgName]	-- ^ binary dependency names (is this a function of relations?)
     }
 
--- |Turn a list of eithers into an either of lists
--- copied from Extra.Either
-concatEithers :: [Either a b] -> Either [a] [b]
-concatEithers xs =
-    case partitionEithers xs of 
-      ([], rs) -> Right rs
-      (ls, _) -> Left ls
-
 -- |Return the dependency info for a source package with the given dependency relaxation.
 -- |According to debian policy, only the first paragraph in debian\/control can be a source package
 -- <http://www.debian.org/doc/debian-policy/ch-controlfields.html#s-sourcecontrolfiles>
-buildDependencies :: Control' Text -> Either String DepInfo
-buildDependencies (Control []) = error "Control file seems to be empty"
-buildDependencies (Control (source:binaries)) =
-    either (Left . concat) (\ rels -> Right (DepInfo {sourceName = sourcePackage, relations = rels, binaryNames = bins})) deps
-    where
-      sourcePackage = maybe (error "First Paragraph in control file lacks a Source field") (SrcPkgName . unpack) $ assoc "Source" source
-      -- The raw list of build dependencies for this package
-      deps = either Left (Right . concat) (concatEithers [buildDeps, buildDepsIndep])
-      buildDeps =
-          case assoc "Build-Depends" source of
-            Just v -> either (\ e -> Left ("Error parsing Build-Depends for" ++ show sourcePackage ++ ": " ++ show e)) Right (parseRelations v)
-            _ -> Right []
-      buildDepsIndep =
-          case assoc "Build-Depends-Indep" source of
-            (Just v) -> either (\ e -> Left ("Error parsing Build-Depends-Indep for" ++ show sourcePackage ++ ": " ++ show e)) Right (parseRelations v)
-            _ -> Right []
-      bins = mapMaybe lookupPkgName binaries
-      lookupPkgName :: Paragraph' Text -> Maybe BinPkgName
-      lookupPkgName p = maybe Nothing (Just . BinPkgName . unpack) (assoc "Package" p)
+buildDependencies :: HasDebianControl control => control -> DepInfo
+buildDependencies control = do
+  DepInfo { sourceName = debianSourcePackageName control
+          , relations = concat [fromMaybe [] (debianBuildDeps control),
+                                fromMaybe [] (debianBuildDepsIndep control)]
+          , binaryNames = debianBinaryPackageNames control }
 
 -- |Specifies build dependencies that should be ignored during the build
 -- decision.  If the pair is (BINARY, Nothing) it means the binary package
@@ -137,18 +120,27 @@ oldRelaxDeps relaxInfo deps =
                 map fst . filter (maybe True (== source) . snd) $ pairs
                 -- concat . map binaries . catMaybes . map snd . filter (\ (_, x) -> maybe True (== source) x) $ pairs
 
+-- | 
+data ReadyTarget a
+    = ReadyTarget { ready :: a
+                  -- ^ Some target whose build dependencies are all satisfied
+                  , waiting :: [a]
+                  -- ^ The targets that are waiting for the ready target
+                  , other :: [a]
+                  -- ^ The rest of the targets that need to be built
+                  }
+
 data BuildableInfo a
-    = BuildableInfo 
-      { readyTriples :: [(a, [a], [a])]
-      , allBlocked :: [a]
-      }
+    = BuildableInfo
+      { readyTargets :: [ReadyTarget a]
+      , allBlocked :: [a] }
     | CycleInfo
       { depPairs :: [(a, a)] }
 
--- |Given an ordering function representing the dependencies on a
--- list of packages, return a triple: One ready package, the packages
--- that depend on the ready package directly or indirectly, and all
--- the other packages.
+-- | Given an ordering function representing the dependencies on a
+-- list of packages, return a ReadyTarget triple: One ready package,
+-- the packages that depend on the ready package directly or
+-- indirectly, and all the other packages.
 buildable :: (a -> a -> Ordering) -> [a] -> BuildableInfo a
 buildable cmp packages =
     -- Find all packages which can't reach any other packages in the
@@ -160,14 +152,15 @@ buildable cmp packages =
       -- We have some buildable packages, return them along with
       -- the list of packages each one directly blocks
       (allReady, blocked) ->
-          BuildableInfo 
-          { readyTriples = map (makeTriple blocked allReady) allReady,
-            allBlocked = map ofVertex blocked }
+          BuildableInfo { readyTargets = map (makeReady blocked allReady) allReady
+                        , allBlocked = map ofVertex blocked }
     where
-      makeTriple blocked ready thisReady =
+      makeReady blocked ready thisReady =
           let otherReady = filter (/= thisReady) ready
               (directlyBlocked, otherBlocked) = partition (\ x -> elem x (reachable isDep thisReady)) blocked in
-          (ofVertex thisReady, map ofVertex directlyBlocked, map ofVertex (otherReady ++ otherBlocked))
+          ReadyTarget { ready = ofVertex thisReady
+                      , waiting = map ofVertex directlyBlocked
+                      , other = map ofVertex (otherReady ++ otherBlocked) }
       --allDeps x = (ofVertex x, map ofVertex (filter (/= x) (reachable hasDep x)))
       isDep = buildG (0, length packages - 1) edges'
       edges' = map (\ (a, b) -> (b, a)) edges''
@@ -251,25 +244,27 @@ compareSource (DepInfo {relations = depends1, binaryNames = bins1}) (DepInfo {re
       checkPackageNameReq (Rel rPkgName _ _) bPkgName = rPkgName == bPkgName
 
 -- |Return the dependency info for a list of control files.
-genDeps :: [FilePath] -> IO (Either String [DepInfo])
-genDeps controlFiles =
-    mapM genDep' controlFiles >>=
-    return . either (Left . concat) (Right . orderSource compareSource) . concatEithers
+genDeps :: [FilePath] -> IO [DepInfo]
+genDeps controlFiles = do
+  orderSource compareSource <$> mapM genDep' controlFiles
     where
-      genDep' :: FilePath -> IO (Either String DepInfo)
+      -- Parse the control file and extract the build dependencies
+      genDep' :: FilePath -> IO DepInfo
       genDep' controlPath = parseControlFromFile controlPath >>=
-                            return . either (Left . show) buildDependencies
+                            either (\ x -> throw (ParseRelationsError [$__LOC__] x))
+                                   (\ x -> validateDebianControl x {- `mapExn` (pushLoc $__LOC__) -} >>= either throw (return . buildDependencies))
+
+-- pushLoc :: Loc -> ControlFileError -> ControlFileError
+-- pushLoc loc e = e {locs = loc : locs e}
 
 -- |One example of how to tie the below functions together. In this
 -- case 'fp' is the path to a directory that contains a bunch of
 -- checked out source packages. The code will automatically look for
 -- debian\/control. It returns a list with the packages in the
 -- order they should be built.
-getSourceOrder :: FilePath -> IO (Either String [SrcPkgName])
+getSourceOrder :: FilePath -> IO [SrcPkgName]
 getSourceOrder fp =
-    findControlFiles fp >>=
-    genDeps >>=
-    return . either Left (Right . map sourceName . orderSource compareSource)
+    findControlFiles fp >>= genDeps >>= return . map sourceName
     where
       -- Return a list of the files that look like debian\/control.
       findControlFiles :: FilePath -> IO [FilePath]
@@ -277,7 +272,3 @@ getSourceOrder fp =
           getDirectoryContents root >>=
           mapM (\ x -> return $ root ++ "/" ++ x ++ "/debian/control") >>=
           filterM doesFileExist
-
-
-assoc :: String -> Paragraph' Text -> Maybe Text
-assoc name fields = maybe Nothing (\ (Field (_, v)) -> Just (stripWS v)) (lookupP name fields)
